import { useEffect, useState } from 'react';
import { useHistory } from 'react-router-dom';
import { effectUtils } from './utils';
import { Subscription } from 'rxjs';
import { UnregisterCallback } from 'history';

export const usePageReadsLogger = () => {
  const [pageReads, setPageReads] = useState(0);
  const [lastPageReads, setLastPageReads] = useState(0);
  const history = useHistory();

  useEffect(() => {
    let pageSubscription: Subscription = null,
      lastPageSubscription: Subscription = null,
      historyUnsubscribe: UnregisterCallback = null;
    effectUtils.init(
      'page',
      setPageReads,
      setLastPageReads,
      () => {
        historyUnsubscribe = history.listen((location, action) => {
          console.log('!!! HISTORY LISTEN CHANGE !!!');
          console.log('!!! Action: ', action);
          console.log('!!! Location: ', location);
        });
      }
    ).then(([pageSub, lastPageSub]) => {
      pageSubscription = pageSub;
      lastPageSubscription = lastPageSub;
    });

    return () => effectUtils.clean(
      pageSubscription,
      lastPageSubscription,
      () => {
        if (historyUnsubscribe) {
          historyUnsubscribe();
        }
      }
    );
  }, [setPageReads, setLastPageReads, history]);

  return [pageReads, lastPageReads];
};
